=================
Contributor Guide
=================

.. toctree::
    :hidden:

    github.rst
    setup.rst
    new_contrib.rst 
    submit.rst
    video.rst
    faq.rst

Espresso is a community project, and we welcome contributions! Ways you can get involved include:

- Add a new test problem (or improve an existing one)
- Improve the infrastructure and the documentation
- Report a bug or suggest a feature using the `Issue Tracker <newissue_>`_
- Join the conversation on `Slack`_

This guide provides step-by-step instructions on how to contribute an Espresso example:

- Step 1 - :doc:`Setting up GitHub <github>`
- Step 2 - :doc:`Installing a development environment <setup>`
- Step 3 - :doc:`Add your example <new_contrib>`
- Step 4 - :doc:`Submit your changes <submit>`

Additionally, we made a :doc:`how-to-contribute video <video>` and collected some 
:doc:`contributor FAQs <faq>`.

There is also a :doc:`../developer_guide/index` that explains some 'behind the scenes' 
aspects of our build system.
